@@ -3,14 +3,12 @@ import time
 from collections import OrderedDict
 from datetime import datetime
 
-from django.contrib.auth.decorators import user_passes_test
+from django.contrib.auth.mixins import LoginRequiredMixin
 from django.utils import timezone
-from django.utils.decorators import method_decorator
 from django.views.generic import TemplateView
 
 from .models import DashboardStats
 
-
 logger = logging.getLogger(__name__)
 
 
@@ -20,6 +18,7 @@ class AdminChartsView(TemplateView):
 
 interval_dateformat_map_bar_chart = {
     'years': ("%Y", "%Y"),
+    'quarters': ("%b %Y", "%b"),
     'months': ("%b %Y", "%b"),
     'weeks': ("%a %d %b %Y", "%W"),
     'days': ("%a %d %b %Y", "%a"),
@@ -28,9 +27,10 @@ interval_dateformat_map_bar_chart = {
 
 interval_dateformat_map = {
     'years': ("%Y", "%Y"),
+    'quarters': ("%b %Y", "%b %Y"),
     'months': ("%b %Y", "%b %Y"),
-    'weeks': ("%a %d %b %Y", "%W (%d %b %Y)"),
-    'days': ("%a %d %b %Y", "%a %d %b %Y"),
+    'weeks': ("%W (%d %b %Y)", "%W"),
+    'days': ("%a %d %b %Y", "%d %b %Y"),
     'hours': ("%a %d %b %Y %H:%S", "%H"),
 }
 
@@ -41,24 +41,32 @@ def get_dateformat(interval, chart_type):
     return interval_dateformat_map[interval]
 
 
-@method_decorator(user_passes_test(lambda u: u.is_superuser), name='dispatch')
 class ChartDataView(TemplateView):
     template_name = 'admin_tools_stats/chart_data.html'
 
     def get_context_data(self, *args, interval=None, graph_key=None, **kwargs):
+        dashboard_stats = DashboardStats.objects.get(graph_key=graph_key)
         context = super().get_context_data(*args, **kwargs)
-        interval = self.request.GET.get('select_box_interval', interval)
-        context['chart_type'] = self.request.GET.get('select_box_chart_type', interval)
+
+        if not(self.request.user.has_perm('admin_tools_stats.view_dashboardstats') or dashboard_stats.show_to_users):
+            context['error'] = "You have no permission to view this chart. Check if you are logged in"
+            context['graph_title'] = dashboard_stats.graph_title
+            return context
+
+        interval = self.request.GET.get('select_box_interval', interval) or dashboard_stats.default_time_scale
+        operation = self.request.GET.get('select_box_operation') or dashboard_stats.type_operation_field_name
+        operation_field = self.request.GET.get('select_box_operation_field') or dashboard_stats.operation_field_name
+        context['chart_type'] = self.request.GET.get('select_box_chart_type') or dashboard_stats.default_chart_type
         try:
             time_since = datetime.strptime(self.request.GET.get('time_since', None), '%Y-%m-%d')
             time_until = datetime.strptime(self.request.GET.get('time_until', None), '%Y-%m-%d')
         except ValueError:
             return context
 
-        dashboard_stats = DashboardStats.objects.get(graph_key=graph_key)
-
         try:
-            series = dashboard_stats.get_multi_time_series(self.request.GET, time_since, time_until, interval, self.request)
+            series = dashboard_stats.get_multi_time_series(
+                self.request.GET, time_since, time_until, interval, operation, operation_field, self.request.user,
+            )
         except Exception as e:
             if 'debug' in self.request.GET:
                 raise e
@@ -69,8 +77,8 @@ class ChartDataView(TemplateView):
         criteria = dashboard_stats.get_multi_series_criteria(self.request.GET)
         if criteria:
             current_tz = timezone.get_current_timezone()
-            time_since_tz = current_tz.localize(time_since)
-            time_until_tz = current_tz.localize(time_until).replace(hour=23, minute=59)
+            time_since_tz = time_since.astimezone(current_tz)
+            time_until_tz = time_until.astimezone(current_tz).replace(hour=23, minute=59)
             choices = criteria.get_dynamic_choices(time_since_tz, time_until_tz)
         else:
             choices = {}
@@ -88,7 +96,7 @@ class ChartDataView(TemplateView):
                 if y_key not in ydata_serie:
                     ydata_serie[y_key] = []
                     names['name%i' % serie_i_map[key]] = str(choices[key][1] if key in choices else key)
-                ydata_serie[y_key].append(value)
+                ydata_serie[y_key].append(value if value else 0)
 
         context['extra'] = {
             'x_is_date': True,
@@ -117,10 +125,30 @@ class ChartDataView(TemplateView):
         return context
 
 
-class AnalyticsView(TemplateView):
-    template_name = 'admin_tools_stats/analytics.html'
+class ChartsMixin:
+    def get_charts_query(self):
+        query = DashboardStats.objects.order_by('graph_title').all()
+        if not self.request.user.has_perm('admin_tools_stats.view_dashboardstats'):
+            query = query.filter(show_to_users=True)
+        return query
+
+
+class AnalyticsView(LoginRequiredMixin, ChartsMixin, TemplateView):
+    def get_template_names(self):
+        if self.request.user.has_perm('admin_tools_stats.view_dashboardstats'):
+            return 'admin_tools_stats/analytics.html'
+        return 'admin_tools_stats/analytics_user.html'
 
     def get_context_data(self, *args, **kwargs):
         context_data = super().get_context_data(*args, **kwargs)
-        context_data['charts'] = DashboardStats.objects.all()
+        context_data['charts'] = self.get_charts_query()
+        return context_data
+
+
+class AnalyticsChartView(LoginRequiredMixin, ChartsMixin, TemplateView):
+    template_name = 'admin_tools_stats/analytics_chart.html'
+
+    def get_context_data(self, *args, graph_key=None, **kwargs):
+        context_data = super().get_context_data(*args, **kwargs)
+        context_data['chart'] = self.get_charts_query().get(graph_key=graph_key)
         return context_data
